summaryrefslogtreecommitdiffstats
path: root/krfb/srvloc/kinetinterfacewatcher.h
diff options
context:
space:
mode:
Diffstat (limited to 'krfb/srvloc/kinetinterfacewatcher.h')
-rw-r--r--krfb/srvloc/kinetinterfacewatcher.h26
1 files changed, 13 insertions, 13 deletions
diff --git a/krfb/srvloc/kinetinterfacewatcher.h b/krfb/srvloc/kinetinterfacewatcher.h
index 399aa3fc..75d72ef8 100644
--- a/krfb/srvloc/kinetinterfacewatcher.h
+++ b/krfb/srvloc/kinetinterfacewatcher.h
@@ -23,10 +23,10 @@
#define KINETINTERFACEWATCHER_H
#include <kinetinterface.h>
-#include <qobject.h>
-#include <qvaluevector.h>
-#include <qcstring.h>
-#include <qstring.h>
+#include <tqobject.h>
+#include <tqvaluevector.h>
+#include <tqcstring.h>
+#include <tqstring.h>
class KInetInterfaceWatcherPrivate;
@@ -43,7 +43,7 @@ class KInetInterfaceWatcherPrivate;
* @see KInetInterface
* @since 3.2
*/
-class KInetInterfaceWatcher : public QObject {
+class KInetInterfaceWatcher : public TQObject {
Q_OBJECT
public:
/**
@@ -51,34 +51,34 @@ public:
* you must @ref start() it.
*
* @param interface the name of the interface to watch (e.g.'eth0')
* or QString::null to watch all interfaces
* @param minInterval the minimum interval between two checks in
* seconds. Be careful not to check too often, to
* avoid unneccessary wasting of CPU time
*/
- KInetInterfaceWatcher(const QString &interface = QString::null,
+ KInetInterfaceWatcher(const TQString &interface = TQString::null,
int minInterval = 60);
/**
* Returns the name of the interface that is being watched.
* @return the name of the interface, or QString::null if all
* interfaces are watched
*/
- QString interface() const;
+ TQString interface() const;
/**
* Starts the KInetInterfaceWatcher. It watches either one
* or all network interfaces. When one of them changed.
* it emits a @ref changed() signal.
* @param interface the name of the interface to watch (e.g.'eth0')
* or QString::null to watch all interfaces
* @param minInterval the minimum interval between two checks in
* seconds. Be careful not to check too often, to
* avoid unneccessary wasting of CPU time
* @see changed()
* @see stop()
*/
- void start(const QString &interface = QString::null,
+ void start(const TQString &interface = TQString::null,
int minInterval = 60);
/**
@@ -109,11 +109,11 @@ signals:
* address has changed.
*
* @param interfaceName the name of the interface that is watched,
* by the emitter, or QString::null if all
* interfaces are being watched
* @see start()
*/
- void changed(QString interfaceName);
+ void changed(TQString interfaceName);
private:
KInetInterfaceWatcherPrivate* d;
@@ -51,34 +51,34 @@ public:
*
* @param interface the name of the interface to watch (e.g.'eth0')
- * or QString::null to watch all interfaces
+ * or TQString::null to watch all interfaces
* @param minInterval the minimum interval between two checks in
* seconds. Be careful not to check too often, to
@@ -51,34 +51,34 @@ public:
/**
* Returns the name of the interface that is being watched.
- * @return the name of the interface, or QString::null if all
+ * @return the name of the interface, or TQString::null if all
* interfaces are watched
*/
@@ -51,34 +51,34 @@ public:
* it emits a @ref changed() signal.
* @param interface the name of the interface to watch (e.g.'eth0')
- * or QString::null to watch all interfaces
+ * or TQString::null to watch all interfaces
* @param minInterval the minimum interval between two checks in
* seconds. Be careful not to check too often, to
@@ -109,11 +109,11 @@ signals:
*
* @param interfaceName the name of the interface that is watched,
- * by the emitter, or QString::null if all
+ * by the emitter, or TQString::null if all
* interfaces are being watched
* @see start()